@@ -25,26 +25,23 @@
 package cli_curr
 
 import (
-	"fmt"
 	"strings"
 
 	"github.com/golang/mock/gomock"
 	"github.com/urfave/cli"
+
 	"go.temporal.io/api/workflowservice/v1"
-
-	"go.temporal.io/server/common/clock"
-	"go.temporal.io/server/common/config"
-
-	"go.temporal.io/server/common"
 	"go.temporal.io/server/common/archiver"
 	"go.temporal.io/server/common/archiver/provider"
 	"go.temporal.io/server/common/cluster"
+	"go.temporal.io/server/common/config"
 	"go.temporal.io/server/common/dynamicconfig"
 	"go.temporal.io/server/common/log"
 	"go.temporal.io/server/common/metrics"
 	"go.temporal.io/server/common/namespace"
 	"go.temporal.io/server/common/persistence"
 	"go.temporal.io/server/common/persistence/client"
+	"go.temporal.io/server/common/primitives"
 	"go.temporal.io/server/common/resolver"
 )
 
@@ -196,44 +193,6 @@ func initializeFrontendClient(
 	return cFactory.FrontendClient(context)
 }
 
-func initializeAdminNamespaceHandler(
-	context *cli.Context,
-) (namespace.Handler, error) {
-
-	configuration := loadConfig(context)
-	logger := log.NewZapLogger(log.BuildZapLogger(configuration.Log))
-	metricsClient := initializeMetricsClient(logger)
-
-	factory := initializePersistenceFactory(
-		&configuration.Persistence,
-		func() int {
-			return dependencyMaxQPS
-		},
-		"",
-		metricsClient,
-		logger,
-	)
-
-	metadataMgr, err := factory.NewMetadataManager()
-	if err != nil {
-		return nil, fmt.Errorf("unable to initialize metadata manager: %v", err)
-	}
-
-	clusterMetadata := initializeClusterMetadata(configuration)
-
-	dynamicConfig := initializeDynamicConfig(configuration, logger)
-
-	return initializeNamespaceHandler(
-		logger,
-		metadataMgr,
-		clusterMetadata,
-		initializeArchivalMetadata(configuration, dynamicConfig),
-		initializeArchivalProvider(configuration, clusterMetadata, metricsClient, logger),
-		nil,
-		nil,
-	), nil
-}
-
 func loadConfig(
 	context *cli.Context,
 ) *config.Config {
@@ -248,33 +207,11 @@ func loadConfig(
 	return &cfg
 }
 
-func initializeNamespaceHandler(
-	logger log.Logger,
-	metadataMgr persistence.MetadataManager,
-	clusterMetadata cluster.Metadata,
-	archivalMetadata archiver.ArchivalMetadata,
-	archiverProvider provider.ArchiverProvider,
-	enableSchedules dynamicconfig.BoolPropertyFnWithNamespaceFilter,
-	timeSource clock.TimeSource,
-) namespace.Handler {
-	return namespace.NewHandler(
-		dynamicconfig.GetIntPropertyFilteredByNamespace(namespace.MaxBadBinaries),
-		logger,
-		metadataMgr,
-		clusterMetadata,
-		initializeNamespaceReplicator(logger),
-		archivalMetadata,
-		archiverProvider,
-		enableSchedules,
-		timeSource,
-	)
-}
-
 func initializePersistenceFactory(
 	pConfig *config.Persistence,
 	maxQps client.PersistenceMaxQps,
 	clusterName string,
-	metricsClient metrics.Client,
+	metricsHandler metrics.Handler,
 	logger log.Logger,
 ) client.Factory {
 
@@ -284,14 +221,14 @@ func initializePersistenceFactory(
 		pConfig,
 		nil, // TODO propagate abstract datastore factory from the CLI.
 		logger,
-		metricsClient,
+		metricsHandler,
 	)
 	return client.FactoryProvider(client.NewFactoryParams{
 		DataStoreFactory:  dataStoreFactory,
 		Cfg:               pConfig,
 		PersistenceMaxQPS: maxQps,
 		ClusterName:       client.ClusterName(clusterName),
-		MetricsClient:     metricsClient,
+		MetricsHandler:    metricsHandler,
 		Logger:            logger,
 	})
 }
@@ -331,7 +268,7 @@ func initializeArchivalMetadata(
 func initializeArchivalProvider(
 	serviceConfig *config.Config,
 	clusterMetadata cluster.Metadata,
-	metricsClient metrics.Client,
+	metricsHandler metrics.Handler,
 	logger log.Logger,
 ) provider.ArchiverProvider {
 
@@ -343,17 +280,17 @@ func initializeArchivalProvider(
 	historyArchiverBootstrapContainer := &archiver.HistoryBootstrapContainer{
 		ExecutionManager: nil, // not used
 		Logger:           logger,
-		MetricsClient:    metricsClient,
+		MetricsHandler:   metricsHandler,
 		ClusterMetadata:  clusterMetadata,
 	}
 	visibilityArchiverBootstrapContainer := &archiver.VisibilityBootstrapContainer{
 		Logger:          logger,
-		MetricsClient:   metricsClient,
+		MetricsHandler:  metricsHandler,
 		ClusterMetadata: clusterMetadata,
 	}
 
 	err := archiverProvider.RegisterBootstrapContainer(
-		common.FrontendServiceName,
+		string(primitives.FrontendService),
 		historyArchiverBootstrapContainer,
 		visibilityArchiverBootstrapContainer,
 	)
@@ -392,10 +329,8 @@ func initializeDynamicConfig(
 	return dynamicconfig.NewCollection(dynamicConfigClient, logger)
 }
 
-func initializeMetricsClient(logger log.Logger) metrics.Client {
-	provider := metrics.MetricsHandlerFromConfig(logger, &metrics.Config{})
-
-	return metrics.NewClient(provider, metrics.Common)
+func initializeMetricsHandler(logger log.Logger) metrics.Handler {
+	return metrics.MetricsHandlerFromConfig(logger, &metrics.Config{})
 }
 
 func getEnvironment(c *cli.Context) string {
